<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Bani
 */

if ( ! function_exists( 'bani_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function bani_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		/* translators: %s: post date. */
		esc_html_x( 'Posted on %s', 'post date', 'bani' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		/* translators: %s: post author. */
		esc_html_x( 'by %s', 'post author', 'bani' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'bani_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function bani_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ' ', 'bani' ) );
		if ( $categories_list && bani_categorized_blog() ) {
			echo '<span class="cat-links">';
			echo wp_kses( $categories_list, array('a' => array(
		        'href' => array(),
		        'title' => array()
		    ),) );
			echo '</span>';
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '<span class="badge bani-badge-secondary">', '</span> <span class="badge bani-badge-secondary">', '</span>' );
		if ( $tags_list ) {
			echo '<span class="tags-links">';
			echo wp_kses( $tags_list, array('a' => array(
		        'href' => array(),
		        'title' => array()
		    ), 'span' => array(
				'class' => array()
			)) );
			echo '</span>';
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link bani-comments-link float-right">';
		comments_popup_link(
			'0 <i class="icon fa fa-comments-o"></i>',
			'1 <i class="icon fa fa-comments-o"></i>',
			'% <i class="icon fa fa-comments-o"></i>'
		);
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			wp_kses(
				/* translators: %s: Name of current post. Only visible to screen readers */
				__( 'Edit <span class="screen-reader-text">%s</span>', 'bani' ),
				array(
					'span' => array(
						'class' => array(),
					),
				)
			),
			get_the_title()
		),
		'<span class="edit-link btn btn-sm btn-secondary">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function bani_categorized_blog() {
	$all_the_cool_cats = get_transient( 'bani_categories' );
	if ( false === $all_the_cool_cats ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'bani_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 || is_preview() ) {
		// This blog has more than 1 category so bani_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so bani_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in bani_categorized_blog.
 */
function bani_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'bani_categories' );
}
add_action( 'edit_category', 'bani_category_transient_flusher' );
add_action( 'save_post',     'bani_category_transient_flusher' );
